@@ -5,8 +5,9 @@ from mini_lambda.generated import *
 from mini_lambda.goodies_generated import *
 from mini_lambda.main import *
 from mini_lambda.main import _
+from mini_lambda.generated2 import *
 from mini_lambda.goodies import *
 
 # allow users to do
 #     import mini_lambda as v
-__all__ = ['base', 'generated', 'goodies_generated', 'main', 'goodies']
+__all__ = ['base', 'generated', 'goodies_generated', 'main', 'generated2', 'goodies']
